@@ -52,11 +52,11 @@ Net::SNMP::Mixin::IfInfo - mixin class for interface related infos
 
 =head1 VERSION
 
-Version 1.00
+Version 1.01
 
 =cut
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 =head1 SYNOPSIS
 
@@ -140,7 +140,7 @@ sub get_if_entries {
       # convert back to OCTET-STRING, maybe already translated by Net::SNMP
       if ( $col eq 'ifPhysAddress' ) {
         $value = hex2octet($value);
-        $value = normalize_mac($value);
+        $value = normalize_mac($value) // $value;
       }
       $result->{$idx}{$col} = $value;
     }
